==> kara-uc-1.1.99.tgz: package/src/kara-uc/components/UCMedal/Card/index.js <==
import React from 'react'
import css from "../index.scss";
import ShowView from '../showView/index'
import ShowViewN from '../showViewN/index'
export default class Card extends React.Component{

    state={
        fadIn:false,//展开与隐藏
        visible:false,//消失隐藏弹框
        list:{}
    }
    handleClick=()=>{
        this.setState({
            fadIn:!this.state.fadIn
        })
    }
    medalshow=(madal)=>{
        this.setState({visible:true,list:madal})
    }
    callback=(res)=>{
        this.setState({visible:res})
    }
    render(){
        const {fadIn,visible,list} = this.state
        const {card,Modal,ConfigStore:{config:{httpAgent}}} = this.props
        const replaceStyle = {
            backgroundColor:'rgba(0,0,0,.1)'
        }
        return(
            <div className={css.cards}>
                <div className={`${css.title} ${css.clearfix}`}>
                    <div className={css.left}>
                        <div className={css.hr}></div>
                        <div className={css.img}>
                            <img src={card.iconUrl} alt={'img'}/>
                        </div>
                        <span>{card.categoryName}</span>
                    </div>
                    <div className={css.right}>
                        <div className={css.text}><em>{card.mineMedalCount}</em>/{card.medalResults.length}</div>
                        {card.medalResults.length>7&&<div onClick={this.handleClick}
                                                          className={`${css.btn} ${'kuc-iconfont'}
                             ${fadIn?'kuc-small-arrow-top-copy':'kuc-small-arrow-bottom-copy'}`}>
                        </div>}

                    </div>
                </div>
                <div className={`${css.contont} ${css.clearfix}`}>
                {card.medalResults.map((o,i)=>{
                        if(!fadIn&&i<7){
                            return (
                                <div className={css.icons} key={i} onClick={()=>this.medalshow(o)}
                                     style={{filter:`${o.won?'':'grayscale(100%)'}`}} >
                                    <div><img src={o.medalIcon} alt={'img'}/></div>
                                    <span>{o.medalName}</span>
                                </div>
                            )
                        }else if(fadIn){
                            return (
                                <div className={css.icons} key={i}
                                     style={{filter:`${o.won?'':'grayscale(100%)'}`}}>
                                    <div><img src={o.medalIcon} alt={'img'}/></div>
                                    <span>{o.medalName}</span>
                                </div>
                            )
                        }
                    }

                )}
                </div>
                <Modal {...{show:visible,replaceStyle}}>
                    {list&&list.won?<ShowView list={list} {...this.props} callback={(res)=>this.callback(res)}/>
                        :<ShowViewN list={list} {...this.props} callback={(res)=>this.callback(res)}/>}
                </Modal>
            </div>
        )
    }
}

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCMedal/Card/index.js <==
import React from 'react'
import css from "../index.scss";
import ShowView from '../showView/index'
import ShowViewN from '../showViewN/index'
export default class Card extends React.Component{

    state={
        fadIn:false,//展开与隐藏
        visible:false,//消失隐藏弹框
        list:{}
    }
    handleClick=()=>{
        this.setState({
            fadIn:!this.state.fadIn
        })
    }
    medalshow=(madal)=>{
        this.setState({visible:true,list:madal})
    }
    closeModal=()=>{
        this.setState({visible:false})
    }
    callback=(res)=>{
        this.setState({visible:res})
    }
    render(){
        const {fadIn,visible,list} = this.state
        const {card,Modal,ConfigStore:{config:{httpAgent}}} = this.props
        const replaceStyle = {
            backgroundColor:'rgba(0,0,0,.1)'
        }
        return(
            <div className={css.cards}>
                <div className={`${css.title} ${css.clearfix}`}>
                    <div className={css.left}>
                        <div className={css.hr}></div>
                        <div className={css.img}>
                            <img src={card.iconUrl} alt={'img'}/>
                        </div>
                        <span>{card.categoryName}</span>
                    </div>
                    <div className={css.right}>
                        <div className={css.text}><em>{card.mineMedalCount}</em>/{card.medalResults.length}</div>
                        {card.medalResults.length>7&&<div onClick={this.handleClick}
                                                          className={`${css.btn} ${'kuc-iconfont'}
                             ${fadIn?'kuc-small-arrow-top-copy':'kuc-small-arrow-bottom-copy'}`}>
                        </div>}

                    </div>
                </div>
                <div className={`${css.contont} ${css.clearfix}`}>
                {card.medalResults.map((o,i)=>{
                        if(!fadIn&&i<7){
                            return (
                                <div className={css.icons} key={i} onClick={()=>this.medalshow(o)}
                                     style={{filter:`${o.won?'':'grayscale(100%)'}`}} >
                                    <div><img src={o.medalIcon} alt={'img'}/></div>
                                    <span>{o.medalName}</span>
                                </div>
                            )
                        }else if(fadIn){
                            return (
                                <div className={css.icons} key={i} onClick={()=>this.medalshow(o)}
                                     style={{filter:`${o.won?'':'grayscale(100%)'}`}}>
                                    <div><img src={o.medalIcon} alt={'img'}/></div>
                                    <span>{o.medalName}</span>
                                </div>
                            )
                        }
                    }

                )}
                </div>
                <Modal {...{show:visible,replaceStyle}} onMask={this.closeModal}>
                    {list&&list.won?<ShowView list={list} {...this.props} callback={(res)=>this.callback(res)}/>
                        :<ShowViewN list={list} {...this.props} callback={(res)=>this.callback(res)}/>}
                </Modal>
            </div>
        )
    }
}
